Learn R Programming

LobsterCatch (version 0.1.0)

rpoisD: This function generates a Poisson or a negative binomial distribution for lobsters in the arena

Description

This function generates a Poisson or a negative binomial distribution for lobsters in the arena

Usage

rpoisD(n, lambda, D = 1)

Value

A vector of integers that is used as initial distribution of lobsters

Arguments

n

is the number of lobsters to be generated

lambda

is the mean density of lobsters

D

is the dispersion index to be used. Default value is 1