distanceToClosestTrap function.This function calculates the Euclidean distance between Trap(s) and each lobster. The function is internally called
in distanceToClosestTrap function.
distanceToTrapCalculator(Lobster, Trap)Returns the distance to trap.
location of lobster in the grid in x and y coordinates.
location of trap in the grid in x and y coordinates.