powered by
This function generates a Poisson or a negative binomial distribution for lobsters in the arena
rpoisD(n, lambda, D = 1)
A vector of integers that is used as initial distribution of lobsters
is the number of lobsters to be generated
is the mean density of lobsters
is the dispersion index to be used. Default value is 1